#include "AMI.h"

#include "defines.h"
#include "util.h"
#include "widgets.h"

#include <array>

constexpr const char* FT_LOGO_PATH = "resources/Fasttube_Logo-white.bmp";
constexpr const char* AVENIR_FONT_PATH = "resources/Avenir-Book.ttf";
constexpr int AVENIR_PTS = 20;
constexpr int FT_LOGO_HEIGHT = 40;
constexpr int GAP = 5;
constexpr int CHOOSE_Y = FT_LOGO_HEIGHT + GAP;
constexpr int MISSION_HEIGHT = 30;

constexpr std::array MISSIONS = {"ACCELERATION",  "SKIDPAD",  "AUTOCROSS",
                                 "TRACKDRIVE",    "EBS TEST", "INSPECTION",
                                 "MANUAL DRIVING"};

AMI::AMI(SDL_Renderer* renderer)
    : View{renderer}, avenir{util::load_font(AVENIR_FONT_PATH, AVENIR_PTS)},
      ft_logo{renderer, FT_LOGO_PATH}, choose{renderer, avenir,
                                              "Choose a mission:"},
      missions_widget{renderer, MISSION_HEIGHT, Alignment::CENTER} {
  ft_logo.set_height(FT_LOGO_HEIGHT);
  ft_logo.set_position(SCREEN_WIDTH / 2, 0);
  ft_logo.set_alignment(Alignment::CENTER);
  widgets.push_back(&ft_logo);

  choose.set_position(SCREEN_WIDTH / 2, CHOOSE_Y);
  choose.set_alignment(Alignment::CENTER);
  widgets.push_back(&choose);

  int choose_height = choose.get_height();
  int missions_y = CHOOSE_Y + choose_height + GAP;
  int missions_height = SCREEN_HEIGHT - CHOOSE_Y - choose_height - 1;
  missions_widget.set_position(0, missions_y);
  missions_widget.set_width(SCREEN_WIDTH, false);
  missions_widget.set_height(missions_height, false);
  for (const auto mission : MISSIONS) {
    missions.push_back(std::make_unique<TextWidget>(renderer, avenir, mission));
  }
  for (const auto& mission : missions) {
    missions_widget.add_element(mission.get());
  }
  widgets.push_back(&missions_widget);
}

void AMI::draw() {
  SDL_SetRenderDrawColor(renderer, 0x00, 0x00, 0x00, 0xFF);
  SDL_RenderClear(renderer);
  for (const auto& widget : widgets) {
    widget->draw();
  }
}